@@ -69,34 +69,21 @@ class DormitoryApplicant(Base):
     """
     __tablename__ = 'univer_dormitory_applicant'
 
-    # Идентификатор
-    id = Column('dormitory_applicant_id', Integer, primary_key=True)
-
-    # Дата и время создания заявления
-    dormitory_applicant_create = Column(DateTime)
-
-    # Факультет
+    id = Column('dormitory_applicant_id', Integer, primary_key=True)  # Идентификатор
+    applicant_create = Column('dormitory_applicant_create', DateTime)  # Дата и время создания заявления
+    applicant_initiator = Column('dormitory_applicant_initiator', Integer)  # Инициатор заявки
     faculty_id = Column(ForeignKey('univer_faculty.faculty_id'))
-    faculty = relationship('Faculty')
-
-    # Общежитие
+    faculty = relationship('Faculty')  # Факультет
     dormitory_id = Column(ForeignKey('platonus_univer_dormitories.dormitoryID'))
-    dormitory = relationship('Dormitory')
-
-    # Статус заявления
-    dormitory_applicant_status = Column(Integer)
-
-    # Статус
-    status = Column(Integer)
-
-    # Год
-    year = Column(Integer)
+    dormitory = relationship('Dormitory')  # Общежитие
+    applicant_status = Column('dormitory_applicant_status', Integer)  # Статус заявки
+    status = Column(Integer)  # Статус
+    year = Column(Integer)  # Год
 
     def __repr__(self):
-        return '<DormitoryApplicant {} (id={})>'.format(self, self.id)
-    
-    def __str__(self):
-        return str(self.dormitory_applicant_create)
+        return '<DormitoryApplicant (id={}, applicant_create={}, dormitory_id={}, applicant_status={}, year={})>'.format(
+            self.id, self.applicant_create, self.dormitory_id, self.applicant_status, self.year
+        )
 
 
 class DormitoryApplicantStudent(Base):
@@ -212,7 +199,7 @@ class DormitoryStudentAccess(Base):
     """
     __tablename__ = 'univer_dormitory_student_access'
 
-    student_id = Column(ForeignKey('univer_students.students_id'))
+    student_id = Column(ForeignKey('univer_students.students_id'), primary_key=True)
     student = relationship('Student')  # Студент
     status = Column('access_status', Integer)  # Статус доступа
     year = Column(Integer)  # Год
